Mu - A Simple Python Code Editor 
================================

.. image:: docs/logo.png

Mu is a simple code editor for beginner programmers based on the feedback given
to and experiences of the Raspberry Pi Foundation's education team. Having said
that, Mu is for anyone who wants to use a simple "no frills" editor.

Mu is a modal editor with modes for Adafruit's CircuitPython, the micro:bit's
version of MicroPython and standard Python 3 (including a graphical debugger).
All modes make available a REPL (either running on the connected CircuitPython
or MicroPython device or as a Jupyter based iPython session in Python3 mode).

It's written in Python and works on Windows, OSX, Linux and Raspberry Pi.

We have `extensive developer documentation <https://mu.readthedocs.io/>`_
including a guide for
`setting up a development environment <https://mu.readthedocs.io/en/latest/setup.html>`_, 
`contributor guidelines <https://mu.readthedocs.io/en/latest/contributing.html>`_ and
`some suggested first steps <https://mu.readthedocs.io/en/latest/first-steps.html>`_.

We want our community to be a friendly place. Therefore, we expect contributors
and collaborators to follow our
`Code of Conduct <https://mu.readthedocs.io/en/latest/code_of_conduct.html>`_.
